@@ -9,9 +9,11 @@ from model_utils.managers import PassThroughManager
 class FuzzyCountQuerySet(QuerySet):
 
     def count(self):
-        is_postgresql = "postgresql" in settings.DATABASES[self.db]["ENGINE"]
+        postgres_engines = ("postgis", "postgresql", "django_postgrespool")
+        engine = settings.DATABASES[self.db]["ENGINE"].split(".")[-1]
+        is_postgres = engine.startswith(postgresql_engines)
         is_filtered = self.query.where or self.query.having
-        if not is_postgresql or is_filtered:
+        if not is_postgres or is_filtered
             return super(FuzzyCountQuerySet, self).count()
         cursor = connections[self.db].cursor()
         cursor.execute("SELECT reltuples FROM pg_class "
